@@ -104,7 +104,7 @@ public class CkanToZenodoPublisherServiceImpl extends RemoteServiceServlet imple
 			//Actually publish to zenodo : 
 			// Step 1 : metadata
 			client= new Ckan2ZenodoImpl();
-			LOG.debug("Calling updatedMetadta for: "+zenodoDepositionPreview);
+			LOG.debug("Calling updatedMetadata for: "+zenodoDepositionPreview);
 			zenodoDepositionPreview = client.updatedMetadata(zenodoDepositionPreview);
 
 			//Step 2 : publish Resources 
